# BallisticCalculator
LGPL library for small arms ballistic calculations (Python 3.9+)

Installation
------------
```python setup.py build_ext --inplace```

Usage
------------
See ```Example.ipynb```


Info
-----
3 Degree-of-Freedom (3DOF+) + spin-drift ballistic calculator.  This version refactored, corrected, and enhanced by David Bookstaber
from version ported to Cython by o-murphy, from versions by Nikolay Gekht:

* The online version of Go documentation is located here: https://godoc.org/github.com/gehtsoft-usa/go_ballisticcalc
* C# version of the package is located here: https://github.com/gehtsoft-usa/BallisticCalculator1
* The online version of C# API documentation is located here: https://gehtsoft-usa.github.io/BallisticCalculator/web-content.html
